@@ -4,6 +4,7 @@ from typing import List
 from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
+from openpyxl.drawing.image import Image
 
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
@@ -51,6 +52,8 @@ class DistributionSheet(Sheet):
                     name=str(image_index),
                     format=image.format,
                     file=image.ref,
+                    width=image.width,
+                    height=image.height,
                 )
             )
 
