@@ -2,7 +2,7 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
-from domain.distribution.distribution_data import DistributionData
+from xlsx_lib.domain.distribution.distribution_data import DistributionData
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
 
